@@ -97,9 +97,9 @@ class Runner(Authenticate):
         return asset, inputs
 
     def _update_headers(self):
-        self.session.headers.update({
+        self.session.headers.update(
             self.inputs.get('headers', {})
-        })
+        )
         return
 
     def get_endpoint(self):
